@@ -6,6 +6,7 @@ use warnings;
     use IO::Prompt;
     use Text::Table;
     use Finance::Bank::NFCU;
+    use Term::ANSIColor::Print;
 }
 
 my ( $access_number, $user_id, $password );
@@ -19,6 +20,18 @@ my ( $access_number, $user_id, $password );
 die "password, userid and account are required\n"
     if !$password || !$user_id || !$access_number;
 
+my $print = Term::ANSIColor::Print->new(
+    alias => {
+        balance   => 'white_on_dark_green',
+        confirmed => 'white_on_dark_green',
+        paid      => 'white_on_dark_green',
+        pending   => 'yellow_on_dark_green',
+        predicted => 'white_on_dark_blue',
+        text      => 'white_on_black',
+    },
+);
+$print->text("\t");
+
 my %credentials = (
     access_number => $access_number,
     user_id       => $user_id,
@@ -38,37 +51,49 @@ my $balances_ra = $nfcu->get_balances();
 die "Your session has (probably) expired."
     if !defined $balances_ra;
 
-print "Balances:\n\n";
+$print->text('Balances:');
 for my $balance_rh (@{ $balances_ra }) {
 
     my $number  = $balance_rh->{account_number};
     my $account = $balance_rh->{account};
     my $dollars = $balance_rh->{balance_str};
 
-    print "$number, $account -- $dollars\n";
+    $print->balance(
+        sprintf "\t% 18s\t% 18s\t% 10s\t",
+        $number,
+        $account,
+        $dollars
+    );
 }
-print "\n";
+$print->text("\t");
 
 my $transaction_ra = $nfcu->get_transactions();
 
-print "All Transactions:\n\n";
+$print->text('All Transactions:');
 for my $transaction_rh ( reverse @{ $transaction_ra } ) {
 
-    my ( $date, $item, $amount_str, $balance_str, $status )
-        = @{ $transaction_rh }{qw( date item amount_str balance_str status )};
+    my ( $date, $item, $category, $amount_str, $balance_str, $status )
+        = @{ $transaction_rh }{qw( date item category amount_str balance_str status )};
 
-    printf "%s\t% 50s\t% 10s\t% 10s\t% 10s\n", $date, $item, $amount_str, $balance_str, $status;
+    $print->$status(
+        sprintf "\t%s\t% 60s\t% 13s\t% 10s\t% 10s\t% 10s\t",
+        $date,
+        $item,
+        $category,
+        $amount_str,
+        $balance_str,
+        $status
+    );
 }
-print "\n";
+$print->text("\t");
 
 my $report_ra = $nfcu->get_expenditure_report();
 
-print "Expenditure Report:\n";
-
 my $tb = Text::Table->new( @{ shift @{ $report_ra } } );
 $tb->load( @{ $report_ra } );
 
-print "\n$tb\n\n";
+$print->text('Expenditure Report:');
+$print->confirmed($tb);
 
 sub categorize {
     my ( $item, $amount ) = @_;
